@@ -1,9 +1,12 @@
+from __future__ import annotations
 from abc import abstractmethod
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from ormlambda import Table, IRepositoryBase
+from ormlambda.common.abstract_classes import NonQueryBase
 
 from .IDelete import IDelete
-from ...utils import Table
-from ...common.interfaces import IRepositoryBase
-from ...common.abstract_classes import NonQueryBase
 
 
 class DeleteQueryBase[T: Table, TRepo: IRepositoryBase](NonQueryBase[T, TRepo], IDelete[T]):
